pub fn asymptotic_normal_form(
expr: &Expr,
) -> Result<Expr, AsymptoticAnalysisError>Expand description
Return a normalized Expr representing the asymptotic behavior of expr.
This is now a compatibility wrapper for big_o_normal_form().
pub fn asymptotic_normal_form(
expr: &Expr,
) -> Result<Expr, AsymptoticAnalysisError>Return a normalized Expr representing the asymptotic behavior of expr.
This is now a compatibility wrapper for big_o_normal_form().