pub struct QuadraticAssignment { /* private fields */ }Expand description
The Quadratic Assignment Problem (QAP).
Given n facilities and m locations, a cost matrix C (n x n) representing flows between facilities, and a distance matrix D (m x m) representing distances between locations, find an injective assignment of facilities to locations that minimizes:
f(p) = sum_{i != j} C[i][j] * D[p(i)][p(j)]
where p is an injective mapping from facilities to locations (a permutation when n == m).
Example
use problemreductions::models::algebraic::QuadraticAssignment;
use problemreductions::{Problem, Solver, BruteForce};
let cost_matrix = vec![
vec![0, 1, 2],
vec![1, 0, 3],
vec![2, 3, 0],
];
let distance_matrix = vec![
vec![0, 5, 8],
vec![5, 0, 3],
vec![8, 3, 0],
];
let problem = QuadraticAssignment::new(cost_matrix, distance_matrix);
let solver = BruteForce::new();
let best = solver.find_witness(&problem);
assert!(best.is_some());Implementations
Sourceimpl QuadraticAssignment
impl QuadraticAssignment
Sourcepub fn cost_matrix(&self) -> &[Vec<i64>]
pub fn cost_matrix(&self) -> &[Vec<i64>]
Get the cost/flow matrix.
Sourcepub fn distance_matrix(&self) -> &[Vec<i64>]
pub fn distance_matrix(&self) -> &[Vec<i64>]
Get the distance matrix.
Sourcepub fn num_facilities(&self) -> usize
pub fn num_facilities(&self) -> usize
Get the number of facilities.
Sourcepub fn num_locations(&self) -> usize
pub fn num_locations(&self) -> usize
Get the number of locations.