pub struct CircuitSAT { /* private fields */ }Expand description
The Circuit SAT problem.
Given a boolean circuit, find variable assignments that satisfy all circuit constraints.
Example
use problemreductions::models::formula::{CircuitSAT, BooleanExpr, Assignment, Circuit};
use problemreductions::{Problem, Solver, BruteForce};
// Create a simple circuit: c = x AND y
let circuit = Circuit::new(vec![
Assignment::new(
vec!["c".to_string()],
BooleanExpr::and(vec![BooleanExpr::var("x"), BooleanExpr::var("y")])
),
]);
let problem = CircuitSAT::new(circuit);
let solver = BruteForce::new();
let solutions = solver.find_all_satisfying(&problem);
// Multiple satisfying assignments exist
assert!(!solutions.is_empty());Implementations
Sourceimpl CircuitSAT
impl CircuitSAT
Sourcepub fn variable_names(&self) -> &[String]
pub fn variable_names(&self) -> &[String]
Get the variable names.
Sourcepub fn num_variables(&self) -> usize
pub fn num_variables(&self) -> usize
Get the number of variables in the circuit.
Sourcepub fn num_assignments(&self) -> usize
pub fn num_assignments(&self) -> usize
Get the number of assignments (constraints) in the circuit.
Sourcepub fn is_valid_solution(&self, config: &[usize]) -> bool
pub fn is_valid_solution(&self, config: &[usize]) -> bool
Check if a configuration is a valid satisfying assignment.