pub struct Maximum2Satisfiability { /* private fields */ }Expand description
Maximum 2-Satisfiability problem where each clause has exactly 2 literals.
Given a set of Boolean variables and a collection of clauses, each containing exactly 2 literals, find a truth assignment that maximizes the number of simultaneously satisfied clauses.
Example
use problemreductions::models::formula::{Maximum2Satisfiability, CNFClause};
use problemreductions::{Problem, BruteForce};
let problem = Maximum2Satisfiability::new(
3,
vec![
CNFClause::new(vec![1, 2]), // x1 OR x2
CNFClause::new(vec![-1, -2]), // NOT x1 OR NOT x2
CNFClause::new(vec![1, 3]), // x1 OR x3
],
);
let solver = BruteForce::new();
let value = solver.solve(&problem).unwrap();Implementations
Sourceimpl Maximum2Satisfiability
impl Maximum2Satisfiability
Sourcepub fn try_new(
num_vars: usize,
clauses: Vec<CNFClause>,
) -> Result<Self, ConstructionError>
pub fn try_new( num_vars: usize, clauses: Vec<CNFClause>, ) -> Result<Self, ConstructionError>
Create a new MAX-2-SAT problem after validating its clauses.
Sourcepub fn num_clauses(&self) -> usize
pub fn num_clauses(&self) -> usize
Get the number of clauses.
Sourcepub fn count_satisfied(
&self,
assignment: &[bool],
) -> Result<i64, EvaluationError>
pub fn count_satisfied( &self, assignment: &[bool], ) -> Result<i64, EvaluationError>
Count satisfied clauses for an assignment.