pub struct BiconnectivityAugmentation<G, W>where
W: WeightElement,{ /* private fields */ }Expand description
The Biconnectivity Augmentation problem.
Given a graph G = (V, E), weighted potential edges, and a budget B,
determine whether there exists a subset of potential edges E' such that:
sum_{e in E'} w(e) <= B(V, E union E')is biconnected
Implementations
Sourceimpl<G: Graph, W: WeightElement> BiconnectivityAugmentation<G, W>
impl<G: Graph, W: WeightElement> BiconnectivityAugmentation<G, W>
Sourcepub fn new(
graph: G,
potential_weights: Vec<(usize, usize, W)>,
budget: W::Sum,
) -> Self
pub fn new( graph: G, potential_weights: Vec<(usize, usize, W)>, budget: W::Sum, ) -> Self
Create a new biconnectivity augmentation instance.
Panics
Panics if any potential edge references a vertex index outside the graph, is a self-loop, duplicates another candidate edge, or already exists in the input graph.
Sourcepub fn potential_weights(&self) -> &[(usize, usize, W)]
pub fn potential_weights(&self) -> &[(usize, usize, W)]
Get the weighted potential edges.
Sourcepub fn num_vertices(&self) -> usize
pub fn num_vertices(&self) -> usize
Get the number of vertices in the underlying graph.
Sourcepub fn num_potential_edges(&self) -> usize
pub fn num_potential_edges(&self) -> usize
Get the number of potential augmentation edges.
Sourcepub fn is_weighted(&self) -> bool
pub fn is_weighted(&self) -> bool
Check if the problem uses a non-unit weight type.