pub struct IsomorphicSpanningTree { /* private fields */ }Expand description
Isomorphic Spanning Tree problem.
Given an undirected graph G = (V, E) and a tree T = (V_T, E_T) with |V| = |V_T|, determine if there exists a bijection π: V_T → V such that for every edge {u, v} in E_T, {π(u), π(v)} is an edge in E.
Example
use problemreductions::models::graph::IsomorphicSpanningTree;
use problemreductions::topology::SimpleGraph;
use problemreductions::{Problem, Solver, BruteForce};
// Host graph: triangle 0-1-2-0
let graph = SimpleGraph::new(3, vec![(0, 1), (1, 2), (0, 2)]);
// Tree: path 0-1-2
let tree = SimpleGraph::new(3, vec![(0, 1), (1, 2)]);
let problem = IsomorphicSpanningTree::new(graph, tree);
let solver = BruteForce::new();
let sol = solver.find_satisfying(&problem);
assert!(sol.is_some());Implementations
Sourceimpl IsomorphicSpanningTree
impl IsomorphicSpanningTree
Sourcepub fn new(graph: SimpleGraph, tree: SimpleGraph) -> Self
pub fn new(graph: SimpleGraph, tree: SimpleGraph) -> Self
Create a new IsomorphicSpanningTree problem.
Panics
Panics if |V(G)| != |V(T)| or if T is not a tree (not connected or wrong number of edges).
Sourcepub fn graph(&self) -> &SimpleGraph
pub fn graph(&self) -> &SimpleGraph
Get a reference to the host graph.
Sourcepub fn tree(&self) -> &SimpleGraph
pub fn tree(&self) -> &SimpleGraph
Get a reference to the target tree.
Sourcepub fn num_vertices(&self) -> usize
pub fn num_vertices(&self) -> usize
Get the number of vertices.
Sourcepub fn num_graph_edges(&self) -> usize
pub fn num_graph_edges(&self) -> usize
Get the number of edges in the host graph.
Sourcepub fn num_tree_edges(&self) -> usize
pub fn num_tree_edges(&self) -> usize
Get the number of edges in the target tree.