pub struct LongestPath<G, W: WeightElement> { /* private fields */ }Expand description
The Longest Path problem.
Given a graph G = (V, E) with positive edge lengths l(e) and
distinguished vertices s and t, find a simple path from s to t
maximizing the total length of its selected edges.
Representation
Each edge is assigned a binary variable:
0: the edge is not selected1: the edge is selected
A valid configuration must select exactly the edges of one simple
undirected path from source_vertex to target_vertex.
Implementations
Sourceimpl<G: Graph, W: WeightElement> LongestPath<G, W>
impl<G: Graph, W: WeightElement> LongestPath<G, W>
Sourcepub fn new(
graph: G,
edge_lengths: Vec<W>,
source_vertex: usize,
target_vertex: usize,
) -> Self
pub fn new( graph: G, edge_lengths: Vec<W>, source_vertex: usize, target_vertex: usize, ) -> Self
Create a new LongestPath instance.
Sourcepub fn edge_lengths(&self) -> &[W]
pub fn edge_lengths(&self) -> &[W]
Get the edge lengths.
Sourcepub fn set_lengths(&mut self, edge_lengths: Vec<W>)
pub fn set_lengths(&mut self, edge_lengths: Vec<W>)
Replace the edge lengths with a new vector.
Sourcepub fn source_vertex(&self) -> usize
pub fn source_vertex(&self) -> usize
Get the source vertex.
Sourcepub fn target_vertex(&self) -> usize
pub fn target_vertex(&self) -> usize
Get the target vertex.
Sourcepub fn is_weighted(&self) -> bool
pub fn is_weighted(&self) -> bool
Check whether this problem uses non-unit edge lengths.
Sourcepub fn num_vertices(&self) -> usize
pub fn num_vertices(&self) -> usize
Get the number of vertices in the graph.
Sourcepub fn is_valid_solution(&self, config: &[usize]) -> bool
pub fn is_valid_solution(&self, config: &[usize]) -> bool
Check if a configuration encodes a valid simple source-target path.