MinimumCostCirculation

Struct MinimumCostCirculation 

pub struct MinimumCostCirculation { /* private fields */ }
Minimum-Cost Circulation problem.

Variables

|A| variables: variable a ranges over {0, ..., c(a)} representing the integral circulation on arc a.

Example

use problemreductions::models::graph::MinimumCostCirculation;
use problemreductions::topology::DirectedGraph;
use problemreductions::{Problem, Solver, BruteForce};

// Two competing cycles 0->1->0 and 0->2->0; the cheaper-per-unit
// cycle 0->2->0 has lower capacity, but pushing both to capacity is
// optimal.
let graph = DirectedGraph::new(3, vec![
    (0, 1), (1, 0), (0, 2), (2, 0),
]);
let problem = MinimumCostCirculation::new(
    graph,
    vec![2, 2, 1, 1],   // capacities
    vec![2, -3, 1, -4], // costs (signed)
);
let solver = BruteForce::new();
let witness = solver.find_witness(&problem).unwrap();
// Optimal cost = 2*2 + 2*(-3) + 1*1 + 1*(-4) = -5.
assert_eq!(problem.total_cost(&witness), -5);

Implementations

Source

impl MinimumCostCirculation

pub fn new(graph: DirectedGraph, capacities: Vec<i64>, costs: Vec<i64>) -> Self

Create a new Minimum-Cost Circulation problem.

Panics

Panics if any of the following holds:

  • capacities.len() != graph.num_arcs()
  • costs.len() != graph.num_arcs()
  • Any capacity is negative

Note: costs are signed and may be negative.

pub fn graph(&self) -> &DirectedGraph

Get a reference to the underlying directed graph.

pub fn capacities(&self) -> &[i64]

Get a reference to the arc capacities.

pub fn costs(&self) -> &[i64]

Get a reference to the arc costs (signed).

pub fn num_vertices(&self) -> usize

Get the number of vertices |V|.

pub fn num_arcs(&self) -> usize

Get the number of arcs |A|.

pub fn is_feasible(&self, config: &[usize]) -> bool

Check whether a circulation assignment is feasible.

A circulation is feasible iff

  1. config.len() == num_arcs,
  2. each 0 <= g(a) <= c(a), and
  3. inflow equals outflow at every vertex (no exempt terminals — this is what distinguishes a circulation from a flow).
pub fn total_cost(&self, config: &[usize]) -> i64

Compute the total cost sum_a a(a) * g(a) of a circulation.