Miscellaneous problems.
Problems with unique input structures that don’t fit other categories:
BinPacking: Bin Packing (minimize bins)Factoring: Integer factorizationFlowShopScheduling: Flow Shop Scheduling (meet deadline on m processors)Knapsack: 0-1 Knapsack (maximize value subject to weight capacity)MultiprocessorScheduling: Schedule tasks on processors to meet a deadlineLongestCommonSubsequence: Longest Common SubsequenceMinimumTardinessSequencing: Minimize tardy tasks in single-machine schedulingPaintShop: Minimize color switches in paint shop schedulingSequencingWithReleaseTimesAndDeadlines: Single-machine scheduling feasibilitySequencingWithinIntervals: Schedule tasks within time windowsShortestCommonSupersequence: Find a common supersequence of bounded lengthStringToStringCorrection: String-to-String Correction (derive target via deletions and swaps)SubsetSum: Find a subset summing to exactly a target valueSumOfSquaresPartition: Partition integers into K groups minimizing sum of squared group sums
Structs
- BinPacking
- The Bin Packing problem.
- Factoring
- The Integer Factoring problem.
- Flow
Shop Scheduling - The Flow Shop Scheduling problem.
- Knapsack
- The 0-1 Knapsack problem.
- Longest
Common Subsequence - The Longest Common Subsequence problem.
- Minimum
Tardiness Sequencing - Minimum Tardiness Sequencing problem.
- Multiprocessor
Scheduling - The Multiprocessor Scheduling problem.
- Paint
Shop - The Paint Shop problem.
- Sequencing
With Release Times AndDeadlines - Sequencing with Release Times and Deadlines.
- Sequencing
Within Intervals - Sequencing Within Intervals problem.
- Shortest
Common Supersequence - The Shortest Common Supersequence problem.
- Staff
Scheduling - The Staff Scheduling problem.
- String
ToString Correction - The String-to-String Correction problem.
- Subset
Sum - The Subset Sum problem.
- SumOf
Squares Partition - The Sum of Squares Partition problem (Garey & Johnson SP19).