pub enum IntExpr {
Atom(u64),
Union(Box<IntExpr>, Box<IntExpr>),
Sum(Box<IntExpr>, Box<IntExpr>),
}Expand description
A recursive integer expression tree.
Represents a set of positive integers built from:
Atom(n): the singleton set {n}Union(f, g): set union F ∪ GSum(f, g): Minkowski sum {m + n : m ∈ F, n ∈ G}
Variants
Atom(u64)
Singleton set {n} for a positive integer n.
Union(Box<IntExpr>, Box<IntExpr>)
Set union: F ∪ G.
Sum(Box<IntExpr>, Box<IntExpr>)
Minkowski sum: {m + n : m ∈ F, n ∈ G}.
Implementations
Sourceimpl IntExpr
impl IntExpr
Sourcepub fn all_atoms_positive(&self) -> bool
pub fn all_atoms_positive(&self) -> bool
Returns true if all atoms in the expression are positive (> 0).
Sourcepub fn count_union_nodes(&self) -> usize
pub fn count_union_nodes(&self) -> usize
Count the number of Union nodes in the expression tree.
Sourcepub fn count_atoms(&self) -> usize
pub fn count_atoms(&self) -> usize
Count the number of Atom nodes in the expression tree.