pub struct EnsembleComputation { /* private fields */ }Implementations
Sourceimpl EnsembleComputation
impl EnsembleComputation
pub fn new( universe_size: usize, subsets: Vec<Vec<usize>>, budget: usize, ) -> Self
Sourcepub fn with_default_budget(
universe_size: usize,
subsets: Vec<Vec<usize>>,
) -> Self
pub fn with_default_budget( universe_size: usize, subsets: Vec<Vec<usize>>, ) -> Self
Create with an automatically derived search-space bound.
The default budget is the sum of all subset sizes (worst-case without intermediate-set reuse). This is always sufficient for the optimal solution to fit within the search space.
Sourcepub fn default_budget(subsets: &[Vec<usize>]) -> usize
pub fn default_budget(subsets: &[Vec<usize>]) -> usize
Compute a default search-space bound from the subsets.
Returns the sum of all subset sizes, clamped to at least 1.
pub fn try_new( universe_size: usize, subsets: Vec<Vec<usize>>, budget: usize, ) -> Result<Self, String>
pub fn universe_size(&self) -> usize
pub fn subsets(&self) -> &[Vec<usize>]
pub fn num_subsets(&self) -> usize
pub fn budget(&self) -> usize