pub struct IntegerExpressionMembership { /* private fields */ }Expand description
The Integer Expression Membership problem.
Given an integer expression e over union (∪) and Minkowski sum (+)
operations on singleton positive integers, and a target integer K,
decide whether K ∈ eval(e).
Configuration
Each Union node has a binary variable (0 = left, 1 = right). A configuration assigns a branch choice to every Union node in DFS order. The expression then collapses to a chain of Sum and Atom nodes, evaluating to a single integer.
Example
use problemreductions::models::misc::{IntegerExpressionMembership, IntExpr};
use problemreductions::{Problem, Solver, BruteForce};
// e = (1 ∪ 4) + (3 ∪ 6) + (2 ∪ 5), target K = 12
let expr = IntExpr::Sum(
Box::new(IntExpr::Sum(
Box::new(IntExpr::Union(
Box::new(IntExpr::Atom(1)),
Box::new(IntExpr::Atom(4)),
)),
Box::new(IntExpr::Union(
Box::new(IntExpr::Atom(3)),
Box::new(IntExpr::Atom(6)),
)),
)),
Box::new(IntExpr::Union(
Box::new(IntExpr::Atom(2)),
Box::new(IntExpr::Atom(5)),
)),
);
let problem = IntegerExpressionMembership::new(expr, 12);
let solver = BruteForce::new();
let solution = solver.find_witness(&problem);
assert!(solution.is_some());Implementations
Sourceimpl IntegerExpressionMembership
impl IntegerExpressionMembership
Sourcepub fn new(expression: IntExpr, target: u64) -> Self
pub fn new(expression: IntExpr, target: u64) -> Self
Create a new IntegerExpressionMembership instance.
Arguments
expression- The integer expression treetarget- The target integer K
Sourcepub fn expression(&self) -> &IntExpr
pub fn expression(&self) -> &IntExpr
Returns a reference to the expression tree.
Sourcepub fn expression_size(&self) -> usize
pub fn expression_size(&self) -> usize
Returns the total number of nodes in the expression tree.
Sourcepub fn num_union_nodes(&self) -> usize
pub fn num_union_nodes(&self) -> usize
Returns the number of Union nodes in the expression tree.
Sourcepub fn expression_depth(&self) -> usize
pub fn expression_depth(&self) -> usize
Returns the depth of the expression tree.
Sourcepub fn evaluate_config(&self, config: &[usize]) -> Option<u64>
pub fn evaluate_config(&self, config: &[usize]) -> Option<u64>
Evaluate the expression for a given config and return the resulting integer.
Returns Some(value) if the config is valid, None otherwise.