pub struct MinimumCodeGenerationParallelAssignments { /* private fields */ }Expand description
The Minimum Code Generation for Parallel Assignments problem.
Given a set V of variables and a collection of assignments A_i: “v_i <- op(B_i)” where v_i is the target variable and B_i is the set of variables read, find a permutation of the assignments that minimizes the number of backward dependencies. A backward dependency occurs when assignment pi(i) writes variable v and assignment pi(j) (j > i) reads v.
Example
use problemreductions::models::misc::MinimumCodeGenerationParallelAssignments;
use problemreductions::{Problem, Solver, BruteForce};
// 4 variables, 4 assignments:
// A_0: a <- op(b, c) -> (0, [1, 2])
// A_1: b <- op(a) -> (1, [0])
// A_2: c <- op(d) -> (2, [3])
// A_3: d <- op(b, c) -> (3, [1, 2])
let assignments = vec![
(0, vec![1, 2]),
(1, vec![0]),
(2, vec![3]),
(3, vec![1, 2]),
];
let problem = MinimumCodeGenerationParallelAssignments::new(4, assignments);
let solver = BruteForce::new();
let solution = solver.find_witness(&problem);
assert!(solution.is_some());Implementations
Sourceimpl MinimumCodeGenerationParallelAssignments
impl MinimumCodeGenerationParallelAssignments
Sourcepub fn new(num_variables: usize, assignments: Vec<(usize, Vec<usize>)>) -> Self
pub fn new(num_variables: usize, assignments: Vec<(usize, Vec<usize>)>) -> Self
Create a new MinimumCodeGenerationParallelAssignments instance.
Panics
Panics if any target variable or read variable index is >= num_variables.
Sourcepub fn num_variables(&self) -> usize
pub fn num_variables(&self) -> usize
Returns the number of variables.
Sourcepub fn num_assignments(&self) -> usize
pub fn num_assignments(&self) -> usize
Returns the number of assignments.
Sourcepub fn assignments(&self) -> &[(usize, Vec<usize>)]
pub fn assignments(&self) -> &[(usize, Vec<usize>)]
Returns the assignments.