pub struct MinimumDecisionTree { /* private fields */ }Expand description
Minimum Decision Tree problem.
Given objects distinguished by binary tests, find a decision tree minimizing the total external path length (sum of leaf depths).
The configuration encodes a flattened complete binary tree of depth
num_objects - 1. Each internal node stores either a test index
(0..num_tests-1) or a sentinel value num_tests meaning “leaf”.
Example
use problemreductions::models::misc::MinimumDecisionTree;
use problemreductions::{Problem, Solver, BruteForce};
let problem = MinimumDecisionTree::new(
vec![
vec![true, true, false, false], // T0
vec![true, false, false, false], // T1
vec![false, true, false, true], // T2
],
4,
3,
);
let solver = BruteForce::new();
let value = solver.solve(&problem);Implementations
Sourceimpl MinimumDecisionTree
impl MinimumDecisionTree
Sourcepub fn new(
test_matrix: Vec<Vec<bool>>,
num_objects: usize,
num_tests: usize,
) -> Self
pub fn new( test_matrix: Vec<Vec<bool>>, num_objects: usize, num_tests: usize, ) -> Self
Create a new MinimumDecisionTree problem.
Panics
- If num_objects < 2 or num_tests < 1
- If test_matrix dimensions don’t match
- If tests don’t distinguish all object pairs
Sourcepub fn num_objects(&self) -> usize
pub fn num_objects(&self) -> usize
Get the number of objects.
Sourcepub fn test_matrix(&self) -> &[Vec<bool>]
pub fn test_matrix(&self) -> &[Vec<bool>]
Get the test matrix.