pub struct MinimumDisjunctiveNormalForm { /* private fields */ }Expand description
Minimum Disjunctive Normal Form problem.
Given a Boolean function by its truth table, find the minimum number of prime implicants whose disjunction (OR) is equivalent to the function.
The constructor computes all prime implicants via Quine-McCluskey. The configuration is a binary selection over prime implicants.
Example
use problemreductions::models::misc::MinimumDisjunctiveNormalForm;
use problemreductions::{Problem, Solver, BruteForce};
// f(x1,x2,x3) = 1 when exactly 1 or 2 variables are true
let truth_table = vec![false, true, true, true, true, true, true, false];
let problem = MinimumDisjunctiveNormalForm::new(3, truth_table);
let solver = BruteForce::new();
let value = solver.solve(&problem);Implementations
Sourceimpl MinimumDisjunctiveNormalForm
impl MinimumDisjunctiveNormalForm
Sourcepub fn new(num_variables: usize, truth_table: Vec<bool>) -> Self
pub fn new(num_variables: usize, truth_table: Vec<bool>) -> Self
Create a new MinimumDisjunctiveNormalForm problem.
Panics
- If truth_table length != 2^num_variables
- If the function is identically false (no minterms)
Sourcepub fn num_variables(&self) -> usize
pub fn num_variables(&self) -> usize
Get the number of variables.
Sourcepub fn truth_table(&self) -> &[bool]
pub fn truth_table(&self) -> &[bool]
Get the truth table.
Sourcepub fn prime_implicants(&self) -> &[PrimeImplicant]
pub fn prime_implicants(&self) -> &[PrimeImplicant]
Get the prime implicants.
Sourcepub fn num_prime_implicants(&self) -> usize
pub fn num_prime_implicants(&self) -> usize
Get the number of prime implicants.