pub struct MinimumExternalMacroDataCompression { /* private fields */ }Expand description
Minimum External Macro Data Compression problem.
Given an alphabet of size k, a string s over {0, ..., k-1}, and
a pointer cost h, find dictionary string D and compressed string C
that minimize cost = |D| + |C| + (h-1) * (pointer count in C).
Representation
The configuration is a vector of 2 * string_length entries:
- First
string_lengthentries are D-slots: each is a symbol index in{0, ..., alphabet_size-1}oralphabet_size(empty/unused). - Next
string_lengthentries are C-slots: each is:- A symbol index in
{0, ..., alphabet_size-1}(literal) alphabet_size(empty/unused)- A value in
{alphabet_size+1, ..., alphabet_size + |s|*(|s|+1)/2}encoding a pointer (start, len) into D.
- A symbol index in
D is the prefix of non-empty D-slots. C is the prefix of non-empty C-slots. The cost is |D| + |C| + (h-1) * (number of pointer symbols in C).
Example
use problemreductions::models::misc::MinimumExternalMacroDataCompression;
use problemreductions::{Problem, Solver, BruteForce};
// Alphabet {a, b}, string "abab", pointer cost h=2
let problem = MinimumExternalMacroDataCompression::new(2, vec![0, 1, 0, 1], 2);
let solver = BruteForce::new();
let solution = solver.find_witness(&problem);
assert!(solution.is_some());Implementations
Sourceimpl MinimumExternalMacroDataCompression
impl MinimumExternalMacroDataCompression
Sourcepub fn new(
alphabet_size: usize,
string: Vec<usize>,
pointer_cost: usize,
) -> Self
pub fn new( alphabet_size: usize, string: Vec<usize>, pointer_cost: usize, ) -> Self
Create a new MinimumExternalMacroDataCompression instance.
Panics
Panics if alphabet_size is 0 and the string is non-empty, or if
any symbol in the string is >= alphabet_size, or if pointer_cost is 0.
Sourcepub fn string_length(&self) -> usize
pub fn string_length(&self) -> usize
Returns the length of the source string.
Sourcepub fn alphabet_size(&self) -> usize
pub fn alphabet_size(&self) -> usize
Returns the alphabet size.
Sourcepub fn pointer_cost(&self) -> usize
pub fn pointer_cost(&self) -> usize
Returns the pointer cost h.