pub struct StaffScheduling { /* private fields */ }Expand description
The Staff Scheduling problem.
Each variable represents how many workers adopt a particular schedule
pattern. A configuration is satisfying iff the total assigned workers does
not exceed num_workers and every period’s staffing requirement is met.
Implementations
Sourceimpl StaffScheduling
impl StaffScheduling
Sourcepub fn new(
shifts_per_schedule: usize,
schedules: Vec<Vec<bool>>,
requirements: Vec<u64>,
num_workers: u64,
) -> Self
pub fn new( shifts_per_schedule: usize, schedules: Vec<Vec<bool>>, requirements: Vec<u64>, num_workers: u64, ) -> Self
Create a new Staff Scheduling instance.
Panics
Panics if num_workers does not fit in usize, if any schedule has a
different number of periods than requirements.len(), or if any
schedule has a number of active periods different from
shifts_per_schedule.
Sourcepub fn num_periods(&self) -> usize
pub fn num_periods(&self) -> usize
Get the number of periods.
Sourcepub fn shifts_per_schedule(&self) -> usize
pub fn shifts_per_schedule(&self) -> usize
Get the required number of active periods per schedule.
Sourcepub fn requirements(&self) -> &[u64]
pub fn requirements(&self) -> &[u64]
Get the staffing requirements.
Sourcepub fn num_workers(&self) -> u64
pub fn num_workers(&self) -> u64
Get the worker budget.
Sourcepub fn num_schedules(&self) -> usize
pub fn num_schedules(&self) -> usize
Get the number of schedule patterns.