pub struct MinimumHittingSet { /* private fields */ }Expand description
The Minimum Hitting Set problem.
Given a universe U and a collection of subsets of U, find a minimum-size
subset H ⊆ U such that H intersects every set in the collection.
Implementations
Sourceimpl MinimumHittingSet
impl MinimumHittingSet
Sourcepub fn new(universe_size: usize, sets: Vec<Vec<usize>>) -> Self
pub fn new(universe_size: usize, sets: Vec<Vec<usize>>) -> Self
Create a new Minimum Hitting Set instance.
Panics
Panics if any set contains an element outside 0..universe_size.
Sourcepub fn universe_size(&self) -> usize
pub fn universe_size(&self) -> usize
Get the universe size.
Sourcepub fn selected_elements(&self, config: &[bool]) -> Option<Vec<usize>>
pub fn selected_elements(&self, config: &[bool]) -> Option<Vec<usize>>
Decode the selected universe elements from a binary configuration.
Sourcepub fn is_valid_solution(&self, config: &[bool]) -> bool
pub fn is_valid_solution(&self, config: &[bool]) -> bool
Check whether a configuration hits every set in the collection.