pub struct SetBasis { /* private fields */ }Expand description
The Set Basis decision problem.
Given a collection C of subsets of a finite set S and an integer k,
determine whether there exists a collection B of exactly k subsets of
S such that every set in C can be expressed as the union of some
subcollection of B.
Implementations
Sourceimpl SetBasis
impl SetBasis
Sourcepub fn new(universe_size: usize, collection: Vec<Vec<usize>>, k: usize) -> Self
pub fn new(universe_size: usize, collection: Vec<Vec<usize>>, k: usize) -> Self
Create a new Set Basis instance.
Panics
Panics if any element in collection lies outside the universe.
Sourcepub fn universe_size(&self) -> usize
pub fn universe_size(&self) -> usize
Return the universe size.
Sourcepub fn basis_size(&self) -> usize
pub fn basis_size(&self) -> usize
Return the required basis size.
Sourcepub fn collection(&self) -> &[Vec<usize>]
pub fn collection(&self) -> &[Vec<usize>]
Return the target collection.
Sourcepub fn is_valid_solution(&self, config: &[usize]) -> bool
pub fn is_valid_solution(&self, config: &[usize]) -> bool
Check whether the configuration is a satisfying Set Basis solution.