pub struct CreateInputInfo {
pub name: &'static str,
pub type_name: &'static str,
pub description: &'static str,
pub required: bool,
pub codec: CreateInputCodec,
}Expand description
A user-facing input accepted when constructing a problem instance.
Fields
name: &'static strInput name in snake_case. Frontends may render it in their native style.
type_name: &'static strConcrete Rust value type accepted by the construction spec.
description: &'static strHuman-readable input description.
required: boolWhether the input must be present.
codec: CreateInputCodecReusable transport syntax for this input.
Implementations
Sourceimpl CreateInputInfo
impl CreateInputInfo
Sourcepub const fn from_field(field: FieldInfo) -> Self
pub const fn from_field(field: FieldInfo) -> Self
Promote catalog field metadata into a required construction input.