pub struct AggregateReductionChain { /* private fields */ }Expand description
A composed aggregate reduction chain produced by
ReductionGraph::reduce_aggregate_along_path.
Implementations
Sourceimpl AggregateReductionChain
impl AggregateReductionChain
Sourcepub fn target_problem_any(&self) -> &dyn Any
pub fn target_problem_any(&self) -> &dyn Any
Get the final target problem as a type-erased reference.
Sourcepub fn target_problem<T: 'static>(&self) -> &T
pub fn target_problem<T: 'static>(&self) -> &T
Get a typed reference to the final target problem.
Panics if the actual target type does not match T.
Sourcepub fn extract_value_dyn(&self, target_value: Value) -> Value
pub fn extract_value_dyn(&self, target_value: Value) -> Value
Extract an aggregate value from target space back to source space.