apply_crossing_gadgets

Function apply_crossing_gadgets 

pub fn apply_crossing_gadgets(
    grid: &mut MappingGrid,
    copylines: &[CopyLine],
) -> Vec<KsgTapeEntry>
Apply all crossing gadgets to the grid. Follows Julia’s algorithm: iterate over all (i,j) pairs and try all patterns. Note: Unlike the previous version, we don’t skip based on crossat position because different (i,j) pairs with the same crossat can match different patterns at different positions (since each pattern has a different cross_location).