map_unweighted_with_method

Function map_unweighted_with_method 

pub fn map_unweighted_with_method(
    num_vertices: usize,
    edges: &[(usize, usize)],
    method: PathDecompositionMethod,
) -> MappingResult<KsgTapeEntry>
Map a graph using a specific path decomposition method (unweighted).

Arguments

  • num_vertices - Number of vertices in the graph
  • edges - List of edges as (u, v) pairs
  • method - The path decomposition method to use for vertex ordering