map_weighted_with_method

Function map_weighted_with_method 

pub fn map_weighted_with_method(
    num_vertices: usize,
    edges: &[(usize, usize)],
    method: PathDecompositionMethod,
) -> MappingResult<WeightedKsgTapeEntry>
Map a graph using a specific path decomposition method (weighted).

Arguments

  • num_vertices - Number of vertices in the graph
  • edges - List of edges as (u, v) pairs
  • method - The path decomposition method to use for vertex ordering