pub fn unapply_gadgets(tape: &[KsgTapeEntry], config: &mut [Vec<usize>])Expand description
Unapply gadgets from tape in reverse order, converting mapped configs to source configs.
pub fn unapply_gadgets(tape: &[KsgTapeEntry], config: &mut [Vec<usize>])Unapply gadgets from tape in reverse order, converting mapped configs to source configs.