pub fn trace_centers(
result: &MappingResult,
) -> Result<Vec<(usize, usize)>, ReductionError>Expand description
Trace each original vertex center through the recorded gadget transformations.
pub fn trace_centers(
result: &MappingResult,
) -> Result<Vec<(usize, usize)>, ReductionError>Trace each original vertex center through the recorded gadget transformations.