pub fn map_config_back(
result: &MappingResult,
grid_config: &[usize],
) -> ExtractionResult<Vec<usize>>Expand description
Read the original vertex configuration at the traced triangular centers.
pub fn map_config_back(
result: &MappingResult,
grid_config: &[usize],
) -> ExtractionResult<Vec<usize>>Read the original vertex configuration at the traced triangular centers.