Struct Expr
pub struct Expr(/* private fields */);Expand description
A cheap, immutable handle to a shared symbolic expression node.
Implementations
impl Expr
impl Expr
pub fn node(&self) -> &ExprNode
pub fn node_identity(&self) -> ExprNodeId
pub fn node_identity(&self) -> ExprNodeId
Identity of this allocation for operation-local DAG memoization. The value is process-local and remains valid while any clone of the node lives.
pub fn integer(value: impl Into<BigInt>) -> Expr
pub fn rational( numerator: impl Into<BigInt>, denominator: impl Into<BigInt>, ) -> Expr
pub fn constant(value: Ratio<BigInt>) -> Expr
pub fn variable(name: impl Into<Box<str>>) -> Expr
pub fn try_variable(name: impl Into<Box<str>>) -> Result<Expr, InvalidSymbol>
pub fn pow(base: Expr, exponent: Expr) -> Expr
pub fn exp(value: Expr) -> Expr
pub fn log(value: Expr) -> Expr
pub fn sqrt(value: Expr) -> Expr
pub fn factorial(value: Expr) -> Expr
pub fn parse(input: &str) -> Expr
pub fn try_parse(input: &str) -> Result<Expr, ParseError>
pub fn variables(&self) -> BTreeSet<&str>
pub fn substitute_complete(
&self,
replacements: &HashMap<&str, &Expr>,
) -> Result<Expr, SubstitutionError>
pub fn substitute_complete( &self, replacements: &HashMap<&str, &Expr>, ) -> Result<Expr, SubstitutionError>
Replace every variable or report the complete set of missing replacements.
pub fn is_constant(&self) -> bool
pub fn is_polynomial(&self) -> bool
pub fn is_valid_complexity_notation(&self) -> bool
pub fn unique_node_count(&self) -> usize