pub struct TriangularSubgraph { /* private fields */ }Expand description
A Triangular Subgraph — an unweighted unit disk graph on a triangular lattice.
Vertices occupy positions on a triangular grid with edges determined by distance.
This is a subtype of UnitDiskGraph in the variant hierarchy.
Physical position for integer coordinates (row, col):
x = row + 0.5if col is even, elsex = rowy = col * sqrt(3)/2
Edges are computed on-the-fly: two positions are connected if their physical Euclidean distance is strictly less than 1.1.
Implementations