pub struct ProblemParameters { /* private fields */ }Expand description
Canonical named parameters for one concrete problem instance.
Implementations
Sourceimpl ProblemParameters
impl ProblemParameters
Sourcepub fn new(components: Vec<(&str, u64)>) -> Self
pub fn new(components: Vec<(&str, u64)>) -> Self
Create problem parameters in canonical declaration order.
Panics
Panics if a parameter name occurs more than once.
Sourcepub fn from_owned(components: Vec<(String, u64)>) -> Self
pub fn from_owned(components: Vec<(String, u64)>) -> Self
Create problem parameters from owned names.
Panics
Panics if a parameter name occurs more than once.