pub struct BottleneckTravelingSalesman { /* private fields */ }Expand description
The Bottleneck Traveling Salesman problem on a simple weighted graph.
Implementations
Sourceimpl BottleneckTravelingSalesman
impl BottleneckTravelingSalesman
Sourcepub fn new(graph: SimpleGraph, edge_weights: Vec<i32>) -> Self
pub fn new(graph: SimpleGraph, edge_weights: Vec<i32>) -> Self
Create a BottleneckTravelingSalesman problem from a graph with edge weights.
Sourcepub fn graph(&self) -> &SimpleGraph
pub fn graph(&self) -> &SimpleGraph
Get a reference to the underlying graph.
Sourcepub fn set_weights(&mut self, weights: Vec<i32>)
pub fn set_weights(&mut self, weights: Vec<i32>)
Set new weights for the problem.
Sourcepub fn num_vertices(&self) -> usize
pub fn num_vertices(&self) -> usize
Get the number of vertices in the underlying graph.
Sourcepub fn is_weighted(&self) -> bool
pub fn is_weighted(&self) -> bool
This model is always weighted.
Sourcepub fn is_valid_solution(&self, config: &[usize]) -> bool
pub fn is_valid_solution(&self, config: &[usize]) -> bool
Check if a configuration is a valid Hamiltonian cycle.