pub struct Factoring { /* private fields */ }Expand description
The Integer Factoring problem.
Given a number to factor, find two integers that multiply to give the target number. Variables represent the bits of the two factors.
Example
use problemreductions::models::misc::Factoring;
use problemreductions::{Problem, Solver, BruteForce};
// Factor 6 with 2-bit factors (allowing factors 0-3)
let problem = Factoring::new(2, 2, 6);
let solver = BruteForce::new();
let solutions = solver.find_all_best(&problem);
// Should find: 2*3=6 or 3*2=6
for sol in &solutions {
let (a, b) = problem.read_factors(sol);
assert_eq!(a * b, 6);
}Implementations
Sourceimpl Factoring
impl Factoring
Sourcepub fn new(m: usize, n: usize, target: u64) -> Self
pub fn new(m: usize, n: usize, target: u64) -> Self
Create a new Factoring problem.
Arguments
m- Number of bits for the first factorn- Number of bits for the second factortarget- The number to factor
Sourcepub fn num_bits_first(&self) -> usize
pub fn num_bits_first(&self) -> usize
Get the number of bits for the first factor (alias for m()).
Sourcepub fn num_bits_second(&self) -> usize
pub fn num_bits_second(&self) -> usize
Get the number of bits for the second factor (alias for n()).
Sourcepub fn read_factors(&self, config: &[usize]) -> (u64, u64)
pub fn read_factors(&self, config: &[usize]) -> (u64, u64)
Read the two factors from a configuration.
The first m bits represent the first factor,
the next n bits represent the second factor.
Sourcepub fn is_valid_solution(&self, config: &[usize]) -> bool
pub fn is_valid_solution(&self, config: &[usize]) -> bool
Check if a configuration is a valid factorization.
Sourcepub fn is_valid_factorization(&self, config: &[usize]) -> bool
pub fn is_valid_factorization(&self, config: &[usize]) -> bool
Check if the configuration is a valid factorization.