pub fn serialize_any(
name: &str,
variant: &BTreeMap<String, String>,
any: &dyn Any,
) -> Option<Value>Expand description
Serialize a &dyn Any by exact problem name and exact variant map.
Returns None if the entry is not found or the downcast fails.