pub fn require_graph_variant(
graph: &ReductionGraph,
problem_ref: &ProblemRef,
) -> Result<ProblemRef, String>Expand description
Check whether a catalog-validated ProblemRef exists in the reduction graph.
Returns the export DTO if the variant is reachable, or an error describing which graph variants exist for the problem.