pub trait ReductionResult {
type Source: Problem;
type Target: Problem;
// Required methods
fn target_problem(&self) -> &Self::Target;
fn extract_solution(&self, target_solution: &[usize]) -> Vec<usize>;
}Expand description
Result of reducing a source problem to a target problem.
This trait encapsulates the target problem and provides methods to extract solutions back to the source problem space.
Required Associated Types
Required Methods
Sourcefn target_problem(&self) -> &Self::Target
fn target_problem(&self) -> &Self::Target
Get a reference to the target problem.