pub fn map_unweighted_with_method(
num_vertices: usize,
edges: &[(usize, usize)],
method: PathDecompositionMethod,
) -> MappingResult<KsgTapeEntry>Expand description
Map a graph using a specific path decomposition method (unweighted).
Arguments
num_vertices- Number of vertices in the graphedges- List of edges as (u, v) pairsmethod- The path decomposition method to use for vertex ordering