pub fn map_unweighted_with_order(
num_vertices: usize,
edges: &[(usize, usize)],
vertex_order: &[usize],
) -> Result<MappingResult<KsgTapeEntry>, ReductionError>Expand description
Map a graph with a specific vertex ordering (unweighted).
Errors
Returns ReductionError if the vertex order, graph, or generated dimensions are invalid.