pub fn map_weighted_with_order(
num_vertices: usize,
edges: &[(usize, usize)],
vertex_order: &[usize],
) -> Result<MappingResult<WeightedKsgTapeEntry>, ReductionError>Expand description
Map a graph with a specific vertex ordering (weighted).
Errors
Returns ReductionError if the vertex order, graph, or generated dimensions are invalid.