pub fn map_graph_triangular_with_order(
num_vertices: usize,
edges: &[(usize, usize)],
vertex_order: &[usize],
) -> MappingResultExpand description
Map a graph to triangular lattice with specific vertex ordering.
Panics
Panics if num_vertices == 0 or if any edge vertex is not in vertex_order.