pub fn smallgraph(name: &str) -> Option<(usize, Vec<(usize, usize)>)>Expand description
Get a small graph by name.
Returns Some((num_vertices, edges)) if the graph exists, None otherwise.
Available graphs: bull, chvatal, cubical, desargues, diamond, dodecahedral, frucht, heawood, house, housex, icosahedral, karate, krackhardtkite, moebiuskantor, octahedral, pappus, petersen, sedgewickmaze, tetrahedral, truncatedcube, truncatedtetrahedron, tutte