OptimizationValue

Trait OptimizationValue 

pub trait OptimizationValue: Aggregate {
    type Inner: Clone + PartialOrd + Debug + Serialize + DeserializeOwned;

    // Required method
    fn meets_bound(value: &Self, bound: &Self::Inner) -> bool;
}
Trait for aggregate values that represent optimization objectives.

Required Associated Types

type Inner: Clone + PartialOrd + Debug + Serialize + DeserializeOwned

The inner numeric type used for comparisons with decision bounds.

Required Methods

fn meets_bound(value: &Self, bound: &Self::Inner) -> bool

Whether this aggregate value satisfies the provided decision bound.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors