pub trait KValue:
VariantParam
+ Clone
+ 'static {
const K: Option<usize>;
}Expand description
K-value marker trait for types that represent a const-generic K parameter.
Types implementing this trait declare an optional K value. None means
the type represents an arbitrary K (like KN), while Some(k) means
a specific value (like K2, K3).
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".